==========================
atelier README
==========================

A collection of tools for software artists

Description
-----------

`atelier` is my collection of tools for managing and
maintaining multiple Python software projects.

It contains

- some general Python utilities (:mod:`atelier.utils`)
- a library for generating reStructuredText from Python (:mod:`atelier.rstgen`)
- some Sphinx extensions (:mod:`atelier.rstgen`)
- a library of fabric commands (:mod:`atelier.fablib`)
- a minimalistic project management (:mod:`atelier.projects`)



Read more on http://atelier.lino-framework.org
